<?php
/**
 * Widget template
 *
 * @package Travel_Gem
 */

$comment_args = array(
	'post_type'     => 'itineraries',
	'number'        => 5,
	'no_found_rows' => false,
	);

$comments_query = new WP_Comment_Query;
$reviews = $comments_query->query( $comment_args );
?>

<aside class="section section-review-carousel heading-<?php echo esc_attr( $instance['heading_alignment'] ); ?>">
		<?php if ( ! empty( $instance['title'] ) ) : ?>
			<?php echo $args['before_title'] . esc_html( $instance['title'] ) . $args['after_title']; ?>
		<?php endif; ?>

		<?php if ( ! empty( $instance['subtitle'] ) ) : ?>
			<p class="widget-subtitle"><?php echo esc_html( $instance['subtitle'] ); ?></p>
		<?php endif; ?>

		<?php if ( class_exists( 'WP_Travel' ) ) : ?>

			<?php if ( $reviews ) : ?>
				<?php
				$carousel_args = array(
					'slidesToShow'   => 2,
					'slidesToScroll' => 1,
					'dots'           => false,
					'prevArrow'      => '<span data-role="none" class="slick-prev" tabindex="0"><i class="fas fa-angle-left" aria-hidden="true"></i></span>',
					'nextArrow'      => '<span data-role="none" class="slick-next" tabindex="0"><i class="fas fa-angle-right" aria-hidden="true"></i></span>',
					'responsive'     => array(
						array(
							'breakpoint' => 1024,
							'settings'   => array(
								'slidesToShow' => 1,
								),
							),
						),
					);

				if ( true === $instance['settings']['enable_autoplay'] ) {
					$carousel_args['autoplay']      = true;
					$carousel_args['autoplaySpeed'] = 1000 * absint( $instance['settings']['transition_delay'] );
				}

				$carousel_args_encoded = wp_json_encode( $carousel_args );
				?>
				<div class="review-carousel-wrapper" data-slick='<?php echo $carousel_args_encoded; ?>'>

					<?php foreach ( $reviews as $review ) : ?>

						<div class="review-item">

							<div class="review-info">
								<div class="review-thumb">
									<?php echo get_avatar( $review->comment_author_email, 150 ); ?>
								</div><!-- .review-thumb -->
								<div class="review-summary">
									<?php $trip_id = $review->comment_post_ID; ?>

									<h4><a href="<?php echo esc_url( get_permalink( $trip_id ) ); ?>"><?php echo esc_html( get_the_title( $trip_id ) ); ?></a></h4>
									<p><?php echo wp_kses_post( $review->comment_content ); ?></p>

									<?php if ( $trip_id ) : ?>
										<div class="review-meta">
											<?php $rating = get_comment_meta( $review->comment_ID, '_wp_travel_rating', true ); ?>
											<?php if ( absint( $rating ) > 0 ) : ?>
												<div class="trip-average-review">
													<span style="width:<?php echo esc_attr( ( $rating / 5 ) * 100 ); ?>%">
														<strong itemprop="ratingValue" class="rating"><?php echo esc_html( $rating ); ?></strong> <?php printf( esc_html__( 'out of %1$s5%2$s', 'travel-gem-pro' ), '<span itemprop="bestRating">', '</span>' ); ?>
													</span>
												</div><!-- .trip-average-review -->
											<?php endif; ?>
										</div><!-- .review-meta -->
										<h3><?php echo esc_html( $review->comment_author ); ?></h3>
									<?php endif; ?>

								</div><!-- .review-summary -->

							</div><!-- .review-info -->

						</div><!-- .review-item  -->
					<?php endforeach; ?>

				</div><!-- .review-carousel-wrapper -->
			<?php endif; ?>

		<?php else : ?>

			<?php if ( current_user_can( 'activate_plugins' ) ) : ?>

				<p><?php esc_html_e( 'WP Travel plugin is not active. Please install and activate the plugin first.', 'travel-gem-pro' ); ?></p>

			<?php endif; ?>

		<?php endif; ?>

</aside><!-- .section section-review-carousel -->
