<?php
/**
 * Showcase widget
 *
 * Widget Name: Travel Gem Showcase
 * Description: Displays showcase blocks
 * Author: WEN Themes
 * Author URI: https://wenthemes.com
 *
 * @package Travel_Gem
 */

/**
 * Showcase widget class.
 *
 * @since 1.0.0
 */
class Travel_Gem_Showcase_Widget extends SiteOrigin_Widget {

	/**
	 * Constructor.
	 *
	 * @since 1.0.0
	 */
	function __construct() {

		parent::__construct(
			'travel-gem-showcase',
			esc_html__( 'Travel Gem: Showcase', 'travel-gem-pro' ),
			array(
				'description' => esc_html__( 'Displays showcase blocks.', 'travel-gem-pro' ),
			),
			array(),
			false,
			plugin_dir_path( __FILE__ )
		);
	}

	/**
	 * Get widget form.
	 *
	 * @since 1.0.0
	 *
	 * @return array Widget form.
	 */
	function get_widget_form() {

		return array(
			'title' => array(
				'type'  => 'text',
				'label' => esc_html__( 'Title', 'travel-gem-pro' ),
				),
			'subtitle' => array(
				'type'  => 'text',
				'label' => esc_html__( 'Subtitle', 'travel-gem-pro' ),
				),
			'heading_alignment' => array(
				'label'   => esc_html__( 'Title/subtitle Alignment', 'travel-gem-pro' ),
				'type'    => 'select',
				'default' => 'center',
				'options' => travel_gem_get_heading_alignment_options(),
				),
			'showcase' => array(
				'type'       => 'repeater',
				'label'      => esc_html__( 'Showcase', 'travel-gem-pro' ),
				'item_name'  => esc_html__( 'Item', 'travel-gem-pro' ),
				'item_label' => array(
					'selector'     => "[id*='showcase-item_title']",
					'update_event' => 'change',
					'value_method' => 'val',
					),
				'fields' => array(
					'item_title' => array(
						'type'        => 'text',
						'label'       => esc_html__( 'Title', 'travel-gem-pro' ),
						'placeholder' => esc_html__( 'Enter item title.', 'travel-gem-pro' ),
						),
					'item_type' => array(
						'type'        => 'text',
						'label'       => esc_html__( 'Type', 'travel-gem-pro' ),
						'description' => esc_html__( 'Enter item type, eg, Real Estate', 'travel-gem-pro' ),
						),
					'item_description' => array(
						'type'  => 'textarea',
						'label' => esc_html__( 'Description', 'travel-gem-pro' ),
						),
					'item_image' => array(
						'type'     => 'media',
						'label'    => esc_html__( 'Image', 'travel-gem-pro' ),
						'library'  => 'image',
						'choose'   => esc_html__( 'Choose Image', 'travel-gem-pro' ),
						'update'   => esc_html__( 'Set Image', 'travel-gem-pro' ),
						'fallback' => true,
						),
					'item_url' => array(
						'type'  => 'link',
						'label' => esc_html__( 'URL', 'travel-gem-pro' ),
						),
					),
				),
			'settings' => array(
				'label'  => esc_html__( 'Settings', 'travel-gem-pro' ),
				'type'   => 'section',
				'hide'   => true,
				'fields' => array(
					'more_button_text' => array(
						'label'   => esc_html__( 'More Button Text', 'travel-gem-pro' ),
						'type'    => 'text',
						'default' => esc_html__( 'Know More', 'travel-gem-pro' ),
						),
					'new_window' => array(
						'label'   => esc_html__( 'Open URL in new window', 'travel-gem-pro' ),
						'type'    => 'checkbox',
						'default' => false,
						),
					),
				),
			);
	}

}

siteorigin_widget_register( 'travel-gem-showcase', __FILE__, 'Travel_Gem_Showcase_Widget' );
