<?php
/**
 * Trips Carousel widget
 *
 * Widget Name: Travel Gem Trips Carousel
 * Description: Displays trips in carousel.
 * Author: WEN Themes
 * Author URI: https://wenthemes.com
 *
 * @package Travel_Gem
 */

/**
 * Trips Carousel widget class.
 *
 * @since 1.0.0
 */
class Travel_Gem_Trips_Carousel_Widget extends SiteOrigin_Widget {

	/**
	 * Constructor.
	 *
	 * @since 1.0.0
	 */
	function __construct() {

		parent::__construct(
			'travel-gem-trips-carousel',
			esc_html__( 'Travel Gem: Trips Carousel', 'travel-gem-pro' ),
			array(
				'description' => esc_html__( 'Displays trips in carousel.', 'travel-gem-pro' ),
			),
			array(),
			false,
			plugin_dir_path( __FILE__ )
		);
	}

	/**
	 * Get widget form.
	 *
	 * @since 1.0.0
	 *
	 * @return array Widget form.
	 */
	function get_widget_form() {

		return array(
			'notice' => array(
				'type'        => 'message',
				'label'       => esc_html__( 'NOTE:', 'travel-gem-pro' ),
				'description' => esc_html__( 'To use this widget, first please make sure \'WP Travel\' plugin is activated and trips are added.', 'travel-gem-pro' ),
				),
			'title' => array(
				'type'  => 'text',
				'label' => esc_html__( 'Title', 'travel-gem-pro' ),
				),
			'subtitle' => array(
				'type'  => 'text',
				'label' => esc_html__( 'Subtitle', 'travel-gem-pro' ),
				),
			'heading_alignment' => array(
				'label'   => esc_html__( 'Title/subtitle Alignment', 'travel-gem-pro' ),
				'type'    => 'select',
				'default' => 'center',
				'options' => travel_gem_get_heading_alignment_options(),
				),
			'post_category' => array(
				'label'           => esc_html__( 'Select Trip Type:', 'travel-gem-pro' ),
				'type'            => 'taxonomy-dropdown',
				'taxonomy'        => 'itinerary_types',
				'show_option_all' => esc_html__( 'All Trip Types', 'travel-gem-pro' ),
				),
			'post_number' => array(
				'label'   => esc_html__( 'Number of Trips', 'travel-gem-pro' ),
				'type'    => 'number',
				'default' => 5,
				),
			'settings' => array(
				'label'  => esc_html__( 'Settings', 'travel-gem-pro' ),
				'type'   => 'section',
				'hide'   => false,
				'fields' => array(
					'enable_autoplay' => array(
						'label'   => esc_html__( 'Enable Autoplay', 'travel-gem-pro' ),
						'type'    => 'checkbox',
						'default' => false,
						),
					'transition_delay' => array(
						'label'       => esc_html__( 'Transition Delay', 'travel-gem-pro' ),
						'description' => esc_html__( 'in seconds', 'travel-gem-pro' ),
						'type'        => 'number',
						'default'     => 4,
						),
					),
				),
			);
	}

	/**
	 * Initialize.
	 *
	 * @since 1.0.0
	 */
	function initialize() {
		$min = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

		$this->register_frontend_scripts(
			array(
				array(
					'jquery-slick',
					get_template_directory_uri() . '/third-party/slick/slick' . $min . '.js',
					array( 'jquery' ),
					'1.5.9',
					),
				)
		);

		$this->register_frontend_styles(
			array(
				array(
					'jquery-slick',
					get_template_directory_uri() . '/third-party/slick/slick' . $min . '.css',
					array(),
					'1.5.9',
					),
				)
		);
	}
}

siteorigin_widget_register( 'travel-gem-trips-carousel', __FILE__, 'Travel_Gem_Trips_Carousel_Widget' );
